@@ -15,7 +15,7 @@ def Not(x: AST):
 
 
 def Iff(x: AST, y: AST):
-    return Ite(x, y, Not(y))
+    return Let([("y", y)], Ite(x, Var("y"), Not(Var("y"))))
 
 
 def And(x: AST, y: AST):
@@ -27,7 +27,7 @@ def Or(x: AST, y: AST):
 
 
 def Xor(x: AST, y: AST):
-    return Ite(x, Not(y), y)
+    return Let([("y", y)], Ite(x, Not(Var("y")), Var("y")))
 
 
 def Implies(x: AST, y: AST):
@@ -127,7 +127,14 @@ LessThanEqualsByteString = wrap_builtin_binop(
 Sha2_256 = wrap_builtin_unop(uplc_ast.BuiltInFun.Sha2_256)
 Sha3_256 = wrap_builtin_unop(uplc_ast.BuiltInFun.Sha3_256)
 Blake2b_256 = wrap_builtin_unop(uplc_ast.BuiltInFun.Blake2b_256)
-VerifySignature = wrap_builtin_unop(uplc_ast.BuiltInFun.VerifySignature)
+VerifySignature = wrap_builtin_ternop(uplc_ast.BuiltInFun.VerifySignature)
+VerifyEd25519Signature = wrap_builtin_ternop(uplc_ast.BuiltInFun.VerifyEd25519Signature)
+VerifyEcdsaSecp256k1Signature = wrap_builtin_ternop(
+    uplc_ast.BuiltInFun.VerifyEcdsaSecp256k1Signature
+)
+VerifySchnorrSecp256k1Signature = wrap_builtin_ternop(
+    uplc_ast.BuiltInFun.VerifySchnorrSecp256k1Signature
+)
 AppendString = wrap_builtin_binop(uplc_ast.BuiltInFun.AppendString)
 EqualsString = wrap_builtin_binop(uplc_ast.BuiltInFun.EqualsString)
 EncodeUtf8 = wrap_builtin_unop(uplc_ast.BuiltInFun.EncodeUtf8)
